@@ -21,7 +21,3 @@
 
 void          bjb_app_menu_set             (GApplication *application) ;
 
-
-void          help_activated               (GSimpleAction *action,
-                                            GVariant      *parameter,
-                                            gpointer       user_data);
