@@ -1,18 +1,18 @@
 /*
  * biji-import-provider.c
- * 
+ *
  * Copyright 2013 Pierre-Yves Luyten <py@luyten.fr>
- * 
+ *
  * bijiben is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
  * Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
- * 
+ *
  * bijiben is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -72,6 +72,10 @@ instanciate_note (BijiImportProvider *self, GFileInfo *info, GFile *container)
   gchar *path;
   GdkRGBA *color;
   BijiManager *manager;
+  GError *error = NULL;
+  BijiInfoSet *set;
+  gchar *html = NULL;
+  GList *notebooks = NULL;
 
 
   retval = NULL;
@@ -86,12 +90,6 @@ instanciate_note (BijiImportProvider *self, GFileInfo *info, GFile *container)
 
 
   /* Deserialize it */
-
-  GError *error = NULL;
-  BijiInfoSet *set;
-  gchar *html = NULL;
-  GList *notebooks = NULL;
-
   biji_tomboy_reader_read   (path,
                              &error,
                              &set,
@@ -234,12 +232,12 @@ biji_import_provider_constructed (GObject *object)
 
   priv->info.unique_id = NULL;
   priv->info.datasource = NULL;
-  priv->info.name = "import-provider";
+  priv->info.name = (gchar *) "import-provider";
   priv->info.icon =  NULL;
   priv->info.domain = NULL;
   priv->info.user = NULL;
 
-  
+
   to_import = g_file_new_for_uri (self->priv->uri);
 
   g_file_enumerate_children_async (to_import, ATTRIBUTES_FOR_NOTEBOOK,
@@ -250,7 +248,7 @@ biji_import_provider_constructed (GObject *object)
 }
 
 
-const BijiProviderInfo *
+static const BijiProviderInfo *
 biji_import_provider_get_info (BijiProvider *self)
 {
   return & (BIJI_IMPORT_PROVIDER (self)->priv->info);
@@ -358,7 +356,9 @@ biji_import_provider_init (BijiImportProvider *self)
 
 
 BijiProvider *
-biji_import_provider_new (BijiManager *b, gchar *target_provider, gchar *uri)
+biji_import_provider_new (BijiManager *b,
+                          const gchar *target_provider,
+                          const gchar *uri)
 {
   return g_object_new (BIJI_TYPE_IMPORT_PROVIDER,
                        "manager", b,
